@@ -41,7 +41,6 @@ import net.sourceforge.plantuml.cucadiagram.Rankdir;
 import net.sourceforge.plantuml.cucadiagram.Stereotype;
 import net.sourceforge.plantuml.cucadiagram.dot.DotSplines;
 import net.sourceforge.plantuml.graphic.HorizontalAlignment;
-import net.sourceforge.plantuml.graphic.SkinParameter;
 import net.sourceforge.plantuml.graphic.color.Colors;
 import net.sourceforge.plantuml.skin.ActorStyle;
 import net.sourceforge.plantuml.skin.ArrowDirection;
@@ -96,8 +95,6 @@ public interface ISkinParam extends ISkinSimple {
 
 	public boolean shadowingForNote(Stereotype stereotype);
 
-	public boolean shadowing2(Stereotype stereotype, SkinParameter skinParameter);
-
 	public PackageStyle packageStyle();
 
 	public ComponentStyle componentStyle();
