@@ -38,7 +38,6 @@ package net.sourceforge.plantuml;
 import java.util.Map;
 
 import net.sourceforge.plantuml.api.ThemeStyle;
-import net.sourceforge.plantuml.ugraphic.color.ColorMapper;
 import net.sourceforge.plantuml.ugraphic.color.HColorSet;
 
 public interface ISkinSimple extends SpriteContainer {
@@ -59,8 +58,6 @@ public interface ISkinSimple extends SpriteContainer {
 
 	public LineBreakStrategy wrapWidth();
 
-	public ColorMapper getColorMapper();
-
 	public void copyAllFrom(ISkinSimple other);
 
 	public double minClassWidth();
