@@ -58,6 +58,7 @@ import net.sourceforge.plantuml.code.NoPlantumlCompressionException;
 import net.sourceforge.plantuml.code.Transcoder;
 import net.sourceforge.plantuml.code.TranscoderUtil;
 import net.sourceforge.plantuml.ftp.FtpServer;
+import net.sourceforge.plantuml.log.Logme;
 import net.sourceforge.plantuml.picoweb.PicoWebServer;
 import net.sourceforge.plantuml.png.MetadataTag;
 import net.sourceforge.plantuml.preproc.Stdlib;
@@ -403,7 +404,7 @@ public class Run {
 					return;
 				}
 			} catch (IOException e) {
-				e.printStackTrace();
+				Logme.error(e);
 			}
 		}
 	}
@@ -426,9 +427,9 @@ public class Run {
 						try {
 							manageFileInternal(f, option, error);
 						} catch (IOException e) {
-							e.printStackTrace();
+							Logme.error(e);
 						} catch (InterruptedException e) {
-							e.printStackTrace();
+							Logme.error(e);
 						}
 						incDone(error.hasError());
 					}
