@@ -36,10 +36,10 @@
 package net.sourceforge.plantuml.creole.atom;
 
 import java.awt.Color;
-import net.sourceforge.plantuml.awt.geom.Dimension2D;
 import java.awt.image.BufferedImage;
 
 import net.sourceforge.plantuml.Dimension2DDouble;
+import net.sourceforge.plantuml.awt.geom.Dimension2D;
 import net.sourceforge.plantuml.graphic.StringBounder;
 import net.sourceforge.plantuml.math.ScientificEquationSafe;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
@@ -101,9 +101,9 @@ public class AtomMath extends AbstractAtom implements Atom {
 	}
 
 	private Color getColor(HColor color, Color defaultValue) {
-		if (color instanceof HColorSimple) {
+		if (color instanceof HColorSimple)
 			return colorMapper.toColor(color);
-		}
+
 		return defaultValue;
 
 	}
