@@ -51,13 +51,13 @@ class Magma {
 	public void putInSquare() {
 		final SquareLinker<ILeaf> linker = new SquareLinker<ILeaf>() {
 			public void topDown(ILeaf top, ILeaf down) {
-				diagram.addLink(new Link(top, down, linkType, Display.NULL, 2, diagram.getSkinParam()
-						.getCurrentStyleBuilder()));
+				diagram.addLink(new Link(diagram.getSkinParam()
+						.getCurrentStyleBuilder(), top, down, linkType, Display.NULL, 2));
 			}
 
 			public void leftRight(ILeaf left, ILeaf right) {
-				diagram.addLink(new Link(left, right, linkType, Display.NULL, 1, diagram.getSkinParam()
-						.getCurrentStyleBuilder()));
+				diagram.addLink(new Link(diagram.getSkinParam()
+						.getCurrentStyleBuilder(), left, right, linkType, Display.NULL, 1));
 			}
 		};
 		new SquareMaker<ILeaf>().putInSquare(standalones, linker);
@@ -103,14 +103,14 @@ class Magma {
 	}
 
 	public void linkToDown(Magma down) {
-		diagram.addLink(new Link(this.getBottomLeft(), down.getTopLeft(), linkType, Display.NULL, 2, diagram
-				.getSkinParam().getCurrentStyleBuilder()));
+		diagram.addLink(new Link(diagram
+				.getSkinParam().getCurrentStyleBuilder(), this.getBottomLeft(), down.getTopLeft(), linkType, Display.NULL, 2));
 
 	}
 
 	public void linkToRight(Magma right) {
-		diagram.addLink(new Link(this.getTopRight(), right.getTopLeft(), linkType, Display.NULL, 1, diagram
-				.getSkinParam().getCurrentStyleBuilder()));
+		diagram.addLink(new Link(diagram
+				.getSkinParam().getCurrentStyleBuilder(), this.getTopRight(), right.getTopLeft(), linkType, Display.NULL, 1));
 	}
 
 }
