@@ -51,7 +51,7 @@ import net.sourceforge.plantuml.graphic.TextBlock;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
 import net.sourceforge.plantuml.ugraphic.ULine;
 import net.sourceforge.plantuml.ugraphic.UTranslate;
-import net.sourceforge.plantuml.ugraphic.color.HColorUtils;
+import net.sourceforge.plantuml.ugraphic.color.HColors;
 
 public class TilesField extends AbstractTextBlock implements TextBlock {
 
@@ -250,7 +250,7 @@ public class TilesField extends AbstractTextBlock implements TextBlock {
 			final double yt = p.getYmin() * dimSingle.getHeight() / 2;
 			t.drawU(ug.apply(new UTranslate((x + xt), (y + yt))));
 		}
-		ug = ug.apply(HColorUtils.RED);
+		ug = ug.apply(HColors.RED);
 		for (Path p : paths) {
 			final TileArea start = p.getStart();
 			final TileArea dest = p.getDest();
