@@ -46,10 +46,9 @@ import net.sourceforge.plantuml.style.PName;
 import net.sourceforge.plantuml.style.Style;
 import net.sourceforge.plantuml.style.Value;
 import net.sourceforge.plantuml.style.ValueNull;
-import net.sourceforge.plantuml.ugraphic.color.ColorUtils;
 import net.sourceforge.plantuml.ugraphic.color.HColor;
 import net.sourceforge.plantuml.ugraphic.color.HColorSet;
-import net.sourceforge.plantuml.ugraphic.color.HColorUtils;
+import net.sourceforge.plantuml.ugraphic.color.HColors;
 import net.sourceforge.plantuml.ugraphic.color.NoSuchColorException;
 
 public class Rainbow {
@@ -91,7 +90,7 @@ public class Rainbow {
 		else
 			colorHead = head.asColor(themeStyle, set);
 		if (colorHead == null)
-			colorHead = HColorUtils.transparent();
+			colorHead = HColors.transparent();
 		return fromColor(color, colorHead);
 	}
 
