@@ -49,6 +49,7 @@ import net.sourceforge.plantuml.core.UmlSource;
 import net.sourceforge.plantuml.json.JsonValue;
 import net.sourceforge.plantuml.jsondiagram.JsonDiagram;
 import net.sourceforge.plantuml.jsondiagram.StyleExtractor;
+import net.sourceforge.plantuml.log.Logme;
 
 public class HclDiagramFactory extends PSystemAbstractFactory {
 
@@ -76,7 +77,7 @@ public class HclDiagramFactory extends PSystemAbstractFactory {
 			HclParser parser = new HclParser(list);
 			data = parser.parseMe();
 		} catch (Exception e) {
-			e.printStackTrace();
+			Logme.error(e);
 		}
 		final JsonDiagram result = new JsonDiagram(style, source, UmlDiagramType.HCL, data, highlighted);
 //		if (styleExtractor != null) {
