@@ -49,6 +49,7 @@ import net.sourceforge.plantuml.command.regex.MyPattern;
 import net.sourceforge.plantuml.command.regex.Pattern2;
 import net.sourceforge.plantuml.core.DiagramType;
 import net.sourceforge.plantuml.core.UmlSource;
+import net.sourceforge.plantuml.log.Logme;
 
 public class PSystemJcckitFactory extends PSystemBasicFactory<PSystemJcckit> {
 
@@ -99,7 +100,7 @@ public class PSystemJcckitFactory extends PSystemBasicFactory<PSystemJcckit> {
 			// p.load(new ByteArrayInputStream(data.toString().getBytes("ISO-8859-1")));
 		} catch (IOException e) {
 			Log.error("Error " + e);
-			e.printStackTrace();
+			Logme.error(e);
 			return null;
 		}
 		return new PSystemJcckit(source, p, width, height);
