@@ -45,6 +45,7 @@ import net.sourceforge.plantuml.StringUtils;
 import net.sourceforge.plantuml.core.DiagramDescription;
 import net.sourceforge.plantuml.core.ImageData;
 import net.sourceforge.plantuml.core.UmlSource;
+import net.sourceforge.plantuml.log.Logme;
 import net.sourceforge.plantuml.ugraphic.color.ColorMapperIdentity;
 import net.sourceforge.plantuml.ugraphic.color.HColor;
 import net.sourceforge.plantuml.ugraphic.color.HColorSet;
@@ -93,7 +94,7 @@ public class PSystemLatex extends AbstractPSystem {
 					scale = scale1;
 				}
 			} catch (Exception e) {
-				e.printStackTrace();
+				Logme.error(e);
 			}
 		} else if (lineLower.startsWith("dpi ")) {
 			final String value = line.substring("dpi ".length());
@@ -103,7 +104,7 @@ public class PSystemLatex extends AbstractPSystem {
 					scale = dpi1 / 96;
 				}
 			} catch (Exception e) {
-				e.printStackTrace();
+				Logme.error(e);
 			}
 		} else {
 			this.latex = line;
