@@ -35,13 +35,12 @@
  */
 package net.sourceforge.plantuml.mindmap;
 
-import net.sourceforge.plantuml.awt.geom.Dimension2D;
-
 import net.sourceforge.plantuml.Dimension2DDouble;
-import net.sourceforge.plantuml.Direction;
 import net.sourceforge.plantuml.ISkinParam;
+import net.sourceforge.plantuml.awt.geom.Dimension2D;
 import net.sourceforge.plantuml.command.CommandExecutionResult;
 import net.sourceforge.plantuml.cucadiagram.Display;
+import net.sourceforge.plantuml.cucadiagram.Rankdir;
 import net.sourceforge.plantuml.graphic.StringBounder;
 import net.sourceforge.plantuml.graphic.UDrawable;
 import net.sourceforge.plantuml.style.NoStyleAvailableException;
@@ -51,8 +50,8 @@ import net.sourceforge.plantuml.ugraphic.color.HColor;
 
 public class MindMap implements UDrawable {
 
-	private final Branch left = new Branch();
-	private final Branch right = new Branch();
+	private final Branch regular = new Branch();
+	private final Branch reverse = new Branch();
 
 	private final ISkinParam skinParam;
 
@@ -61,74 +60,79 @@ public class MindMap implements UDrawable {
 	}
 
 	private void computeFinger() {
-		if (this.left.hasFinger() == false && this.right.hasFinger() == false) {
-			if (this.left.hasChildren())
-				left.initFinger(skinParam, Direction.LEFT);
+		if (this.reverse.hasFinger() == false && this.regular.hasFinger() == false) {
+			if (this.reverse.hasChildren())
+				reverse.initFinger(skinParam, false);
 
-			if (this.left.hasFinger() == false || this.right.hasChildren())
-				right.initFinger(skinParam, Direction.RIGHT);
+			if (this.reverse.hasFinger() == false || this.regular.hasChildren())
+				regular.initFinger(skinParam, true);
 
-			if (this.left.hasFinger() && this.right.hasFinger())
-				this.left.doNotDrawFirstPhalanx();
+			if (this.reverse.hasFinger() && this.regular.hasFinger())
+				this.reverse.doNotDrawFirstPhalanx();
 
 		}
 	}
 
 	Dimension2D calculateDimension(StringBounder stringBounder) {
 		this.computeFinger();
-		final double y1 = this.right.getHalfThickness(stringBounder);
-		final double y2 = this.left.getHalfThickness(stringBounder);
+		final double y1 = this.regular.getHalfThickness(stringBounder);
+		final double y2 = this.reverse.getHalfThickness(stringBounder);
 		final double y = Math.max(y1, y2);
 
-		final double x = this.left.getFullElongation(stringBounder);
-
-		final double width = x + this.right.getFullElongation(stringBounder);
+		final double width = this.reverse.getX12(stringBounder) + this.regular.getX12(stringBounder);
 		final double height = y
-				+ Math.max(this.left.getHalfThickness(stringBounder), this.right.getHalfThickness(stringBounder));
-		return new Dimension2DDouble(width, height);
+				+ Math.max(this.reverse.getHalfThickness(stringBounder), this.regular.getHalfThickness(stringBounder));
+		if (skinParam.getRankdir() == Rankdir.TOP_TO_BOTTOM)
+			return new Dimension2DDouble(height, width);
+		else
+			return new Dimension2DDouble(width, height);
 
 	}
 
 	@Override
 	public void drawU(UGraphic ug) {
-		if (this.left.hasRoot() == false && this.right.hasRoot() == false)
+		if (this.reverse.hasRoot() == false && this.regular.hasRoot() == false)
 			return;
 
 		this.computeFinger();
 
 		final StringBounder stringBounder = ug.getStringBounder();
-		final double y1 = this.right.getHalfThickness(stringBounder);
-		final double y2 = this.left.getHalfThickness(stringBounder);
+		final double y1 = this.regular.getHalfThickness(stringBounder);
+		final double y2 = this.reverse.getHalfThickness(stringBounder);
 		final double y = Math.max(y1, y2);
 
-		final double x = this.left.getX12(stringBounder);
-		this.right.drawU(ug.apply(new UTranslate(x, y)));
-		this.left.drawU(ug.apply(new UTranslate(x, y)));
+		final double x = this.reverse.getX12(stringBounder);
+		if (skinParam.getRankdir() == Rankdir.TOP_TO_BOTTOM)
+			ug = ug.apply(new UTranslate(y, x));
+		else
+			ug = ug.apply(new UTranslate(x, y));
+		this.regular.drawU(ug);
+		this.reverse.drawU(ug);
 	}
 
 	CommandExecutionResult addIdeaInternal(String stereotype, HColor backColor, int level, Display label,
-			IdeaShape shape, Direction direction) {
+			IdeaShape shape, boolean direction) {
 		try {
-			if (this.left.hasRoot() == false && this.right.hasRoot() == false)
+			if (this.reverse.hasRoot() == false && this.regular.hasRoot() == false)
 				level = 0;
 
 			if (level == 0) {
-				this.right.initRoot(skinParam.getCurrentStyleBuilder(), backColor, label, shape, stereotype);
-				this.left.initRoot(skinParam.getCurrentStyleBuilder(), backColor, label, shape, stereotype);
+				this.regular.initRoot(skinParam.getCurrentStyleBuilder(), backColor, label, shape, stereotype);
+				this.reverse.initRoot(skinParam.getCurrentStyleBuilder(), backColor, label, shape, stereotype);
 				return CommandExecutionResult.ok();
 			}
-			if (direction == Direction.LEFT)
-				return this.left.add(skinParam.getCurrentStyleBuilder(), backColor, level, label, shape, stereotype);
+			if (direction == false)
+				return this.reverse.add(skinParam.getCurrentStyleBuilder(), backColor, level, label, shape, stereotype);
 
-			return this.right.add(skinParam.getCurrentStyleBuilder(), backColor, level, label, shape, stereotype);
+			return this.regular.add(skinParam.getCurrentStyleBuilder(), backColor, level, label, shape, stereotype);
 		} catch (NoStyleAvailableException e) {
-			// e.printStackTrace();
+			// Logme.error(e);
 			return CommandExecutionResult.error("General failure: no style available.");
 		}
 	}
 
 	boolean isFull(int level) {
-		return level == 0 && this.right.hasRoot();
+		return level == 0 && this.regular.hasRoot();
 	}
 
 }
