@@ -78,11 +78,11 @@ public abstract class AbstractClassOrObjectDiagram extends AbstractEntityDiagram
 		if (link == null) {
 			return false;
 		}
-		final Link l1 = new Link(entity1, node, link.getType(), link.getLabel(), link.getLength(), link.getQualifier1(),
-				null, link.getLabeldistance(), link.getLabelangle(), getSkinParam().getCurrentStyleBuilder());
-		final Link l2 = new Link(node, entity2, link.getType(), link.getLabel(), link.getLength(), null,
-				link.getQualifier2(), link.getLabeldistance(), link.getLabelangle(),
-				getSkinParam().getCurrentStyleBuilder());
+		final Link l1 = new Link(getSkinParam().getCurrentStyleBuilder(), entity1, node, link.getType(), link.getLabel(), link.getLength(),
+				link.getQualifier1(), null, link.getLabeldistance(), link.getLabelangle());
+		final Link l2 = new Link(getSkinParam().getCurrentStyleBuilder(), node, entity2, link.getType(), link.getLabel(), link.getLength(),
+				null, link.getQualifier2(), link.getLabeldistance(),
+				link.getLabelangle());
 		addLink(l1);
 		addLink(l2);
 		removeLink(link);
@@ -147,8 +147,8 @@ public abstract class AbstractClassOrObjectDiagram extends AbstractEntityDiagram
 			insertPointBetween(entity2A, entity2B, point2);
 
 			final int length = 1;
-			final Link point1ToPoint2 = new Link(point1, point2, linkType, label, length,
-					getSkinParam().getCurrentStyleBuilder());
+			final Link point1ToPoint2 = new Link(getSkinParam().getCurrentStyleBuilder(), point1, point2, linkType, label,
+					length);
 			addLink(point1ToPoint2);
 
 			return CommandExecutionResult.ok();
@@ -159,8 +159,8 @@ public abstract class AbstractClassOrObjectDiagram extends AbstractEntityDiagram
 	private void insertPointBetween(final IEntity entity1A, final IEntity entity1B, final IEntity point1) {
 		Link existingLink1 = foundLink(entity1A, entity1B);
 		if (existingLink1 == null) {
-			existingLink1 = new Link(entity1A, entity1B, new LinkType(LinkDecor.NONE, LinkDecor.NONE), Display.NULL, 2,
-					getSkinParam().getCurrentStyleBuilder());
+			existingLink1 = new Link(getSkinParam().getCurrentStyleBuilder(), entity1A, entity1B, new LinkType(LinkDecor.NONE, LinkDecor.NONE), Display.NULL,
+					2);
 		} else {
 			removeLink(existingLink1);
 		}
@@ -170,14 +170,14 @@ public abstract class AbstractClassOrObjectDiagram extends AbstractEntityDiagram
 		final IEntity entity2real = existingLink1.isInverted() ? existingLink1.getEntity1()
 				: existingLink1.getEntity2();
 
-		final Link entity1ToPoint = new Link(entity1real, point1, existingLink1.getType().getPart2(),
-				existingLink1.getLabel(), existingLink1.getLength(), existingLink1.getQualifier1(), null,
-				existingLink1.getLabeldistance(), existingLink1.getLabelangle(),
-				getSkinParam().getCurrentStyleBuilder());
+		final Link entity1ToPoint = new Link(getSkinParam().getCurrentStyleBuilder(), entity1real, point1,
+				existingLink1.getType().getPart2(), existingLink1.getLabel(), existingLink1.getLength(), existingLink1.getQualifier1(),
+				null, existingLink1.getLabeldistance(),
+				existingLink1.getLabelangle());
 		entity1ToPoint.setLinkArrow(existingLink1.getLinkArrow());
-		final Link pointToEntity2 = new Link(point1, entity2real, existingLink1.getType().getPart1(), Display.NULL,
-				existingLink1.getLength(), null, existingLink1.getQualifier2(), existingLink1.getLabeldistance(),
-				existingLink1.getLabelangle(), getSkinParam().getCurrentStyleBuilder());
+		final Link pointToEntity2 = new Link(getSkinParam().getCurrentStyleBuilder(), point1, entity2real, existingLink1.getType().getPart1(),
+				Display.NULL, existingLink1.getLength(), null, existingLink1.getQualifier2(),
+				existingLink1.getLabeldistance(), existingLink1.getLabelangle());
 
 		// int length = 1;
 		// if (existingLink.getLength() == 1 && entity1A != entity1B) {
@@ -268,8 +268,8 @@ public abstract class AbstractClassOrObjectDiagram extends AbstractEntityDiagram
 		void createNew(int mode, LinkType linkType, Display label) {
 			existingLink = foundLink(entity1, entity2);
 			if (existingLink == null) {
-				existingLink = new Link(entity1, entity2, new LinkType(LinkDecor.NONE, LinkDecor.NONE), Display.NULL, 2,
-						getSkinParam().getCurrentStyleBuilder());
+				existingLink = new Link(getSkinParam().getCurrentStyleBuilder(), entity1, entity2, new LinkType(LinkDecor.NONE, LinkDecor.NONE), Display.NULL,
+						2);
 			} else {
 				removeLink(existingLink);
 			}
@@ -279,13 +279,13 @@ public abstract class AbstractClassOrObjectDiagram extends AbstractEntityDiagram
 			final IEntity entity2real = existingLink.isInverted() ? existingLink.getEntity1()
 					: existingLink.getEntity2();
 
-			entity1ToPoint = new Link(entity1real, point, existingLink.getType().getPart2(), existingLink.getLabel(),
-					existingLink.getLength(), existingLink.getQualifier1(), null, existingLink.getLabeldistance(),
-					existingLink.getLabelangle(), getSkinParam().getCurrentStyleBuilder());
+			entity1ToPoint = new Link(getSkinParam().getCurrentStyleBuilder(), entity1real, point, existingLink.getType().getPart2(),
+					existingLink.getLabel(), existingLink.getLength(), existingLink.getQualifier1(), null,
+					existingLink.getLabeldistance(), existingLink.getLabelangle());
 			entity1ToPoint.setLinkArrow(existingLink.getLinkArrow());
-			pointToEntity2 = new Link(point, entity2real, existingLink.getType().getPart1(), Display.NULL,
-					existingLink.getLength(), null, existingLink.getQualifier2(), existingLink.getLabeldistance(),
-					existingLink.getLabelangle(), getSkinParam().getCurrentStyleBuilder());
+			pointToEntity2 = new Link(getSkinParam().getCurrentStyleBuilder(), point, entity2real, existingLink.getType().getPart1(),
+					Display.NULL, existingLink.getLength(), null, existingLink.getQualifier2(),
+					existingLink.getLabeldistance(), existingLink.getLabelangle());
 
 			int length = 1;
 			if (existingLink.getLength() == 1 && entity1 != entity2) {
@@ -304,11 +304,11 @@ public abstract class AbstractClassOrObjectDiagram extends AbstractEntityDiagram
 			addLink(pointToEntity2);
 
 			if (mode == 1) {
-				pointToAssocied = new Link(point, associed, linkType, label, length,
-						getSkinParam().getCurrentStyleBuilder());
+				pointToAssocied = new Link(getSkinParam().getCurrentStyleBuilder(), point, associed, linkType, label,
+						length);
 			} else {
-				pointToAssocied = new Link(associed, point, linkType, label, length,
-						getSkinParam().getCurrentStyleBuilder());
+				pointToAssocied = new Link(getSkinParam().getCurrentStyleBuilder(), associed, point, linkType, label,
+						length);
 			}
 			addLink(pointToAssocied);
 		}
@@ -316,18 +316,18 @@ public abstract class AbstractClassOrObjectDiagram extends AbstractEntityDiagram
 		void createInSecond(LinkType linkType, Display label) {
 			existingLink = foundLink(entity1, entity2);
 			if (existingLink == null) {
-				existingLink = new Link(entity1, entity2, new LinkType(LinkDecor.NONE, LinkDecor.NONE), Display.NULL, 2,
-						getSkinParam().getCurrentStyleBuilder());
+				existingLink = new Link(getSkinParam().getCurrentStyleBuilder(), entity1, entity2, new LinkType(LinkDecor.NONE, LinkDecor.NONE), Display.NULL,
+						2);
 			} else {
 				removeLink(existingLink);
 			}
 
-			entity1ToPoint = new Link(entity1, point, existingLink.getType().getPart2(), existingLink.getLabel(), 2,
-					existingLink.getQualifier1(), null, existingLink.getLabeldistance(), existingLink.getLabelangle(),
-					getSkinParam().getCurrentStyleBuilder());
-			pointToEntity2 = new Link(point, entity2, existingLink.getType().getPart1(), Display.NULL, 2, null,
-					existingLink.getQualifier2(), existingLink.getLabeldistance(), existingLink.getLabelangle(),
-					getSkinParam().getCurrentStyleBuilder());
+			entity1ToPoint = new Link(getSkinParam().getCurrentStyleBuilder(), entity1, point, existingLink.getType().getPart2(), existingLink.getLabel(),
+					2, existingLink.getQualifier1(), null, existingLink.getLabeldistance(),
+					existingLink.getLabelangle());
+			pointToEntity2 = new Link(getSkinParam().getCurrentStyleBuilder(), point, entity2, existingLink.getType().getPart1(), Display.NULL, 2,
+					null, existingLink.getQualifier2(), existingLink.getLabeldistance(),
+					existingLink.getLabelangle());
 			// entity1ToPoint = new Link(entity1, point, existingLink.getType(),
 			// null, 2);
 			// pointToEntity2 = new Link(point, entity2, existingLink.getType(),
@@ -339,11 +339,11 @@ public abstract class AbstractClassOrObjectDiagram extends AbstractEntityDiagram
 				other.pointToAssocied = other.pointToAssocied.getInv();
 				addLink(other.pointToAssocied);
 			}
-			pointToAssocied = new Link(point, associed, linkType, label, 1, getSkinParam().getCurrentStyleBuilder());
+			pointToAssocied = new Link(getSkinParam().getCurrentStyleBuilder(), point, associed, linkType, label, 1);
 			addLink(pointToAssocied);
 
-			final Link lnode = new Link(other.point, this.point, new LinkType(LinkDecor.NONE, LinkDecor.NONE),
-					Display.NULL, 1, getSkinParam().getCurrentStyleBuilder());
+			final Link lnode = new Link(getSkinParam().getCurrentStyleBuilder(), other.point, this.point,
+					new LinkType(LinkDecor.NONE, LinkDecor.NONE), Display.NULL, 1);
 			lnode.setInvis(true);
 			addLink(lnode);
 
