@@ -69,6 +69,7 @@ import net.sourceforge.plantuml.core.ImageData;
 import net.sourceforge.plantuml.error.PSystemError;
 import net.sourceforge.plantuml.error.PSystemErrorUtils;
 import net.sourceforge.plantuml.graphic.QuoteUtils;
+import net.sourceforge.plantuml.log.Logme;
 import net.sourceforge.plantuml.security.SFile;
 import net.sourceforge.plantuml.version.Version;
 
@@ -138,7 +139,7 @@ public class PicoWebServer implements Runnable {
 			try {
 				sendError(e, out);
 			} catch (Throwable e1) {
-				e.printStackTrace();
+				Logme.error(e);
 			}
 		} finally {
 			try {
@@ -146,7 +147,7 @@ public class PicoWebServer implements Runnable {
 				out.close();
 				connect.close();
 			} catch (Throwable e) {
-				e.printStackTrace();
+				Logme.error(e);
 			}
 		}
 	}
@@ -223,6 +224,7 @@ public class PicoWebServer implements Runnable {
 		write(out, "Cache-Control: no-cache");
 		write(out, "Server: PlantUML PicoWebServer " + Version.versionString());
 		write(out, "Date: " + new Date());
+		write(out, "Access-Control-Allow-Origin: *");
 		write(out, "Content-type: " + fileFormatOption.getFileFormat().getMimeType());
 		write(out, "Content-length: " + fileData.length);
 		write(out, "X-PlantUML-Diagram-Width: " + imageData.getWidth());
