@@ -35,7 +35,6 @@
  */
 package net.sourceforge.plantuml.project.draw;
 
-import net.sourceforge.plantuml.awt.geom.Dimension2D;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.TreeSet;
@@ -43,6 +42,7 @@ import java.util.TreeSet;
 import net.sourceforge.plantuml.ISkinParam;
 import net.sourceforge.plantuml.LineBreakStrategy;
 import net.sourceforge.plantuml.SpriteContainerEmpty;
+import net.sourceforge.plantuml.awt.geom.Dimension2D;
 import net.sourceforge.plantuml.creole.CreoleMode;
 import net.sourceforge.plantuml.creole.Parser;
 import net.sourceforge.plantuml.creole.Sheet;
@@ -69,17 +69,10 @@ import net.sourceforge.plantuml.style.SName;
 import net.sourceforge.plantuml.style.Style;
 import net.sourceforge.plantuml.style.StyleBuilder;
 import net.sourceforge.plantuml.style.StyleSignatureBasic;
-import net.sourceforge.plantuml.style.Value;
 import net.sourceforge.plantuml.svek.image.Opale;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
-import net.sourceforge.plantuml.ugraphic.ULine;
-import net.sourceforge.plantuml.ugraphic.URectangle;
-import net.sourceforge.plantuml.ugraphic.UStroke;
 import net.sourceforge.plantuml.ugraphic.UTranslate;
 import net.sourceforge.plantuml.ugraphic.color.HColor;
-import net.sourceforge.plantuml.ugraphic.color.HColorNone;
-import net.sourceforge.plantuml.ugraphic.color.HColorSet;
-import net.sourceforge.plantuml.ugraphic.color.HColorUtils;
 
 public class TaskDrawRegular extends AbstractTaskDraw {
 
@@ -90,12 +83,10 @@ public class TaskDrawRegular extends AbstractTaskDraw {
 	private final Collection<GanttConstraint> constraints;
 	private final ISkinParam skinParam;
 
-	// private final double margin = 2;
-
 	public TaskDrawRegular(TimeScale timeScale, Real y, String prettyDisplay, Day start, Day end, boolean oddStart,
 			boolean oddEnd, ISkinParam skinParam, Task task, ToTaskDraw toTaskDraw,
-			Collection<GanttConstraint> constraints, StyleBuilder styleBuilder, HColorSet colorSet) {
-		super(timeScale, y, prettyDisplay, start, skinParam, task, toTaskDraw, styleBuilder, colorSet);
+			Collection<GanttConstraint> constraints, StyleBuilder styleBuilder) {
+		super(timeScale, y, prettyDisplay, start, skinParam, task, toTaskDraw, styleBuilder);
 		this.skinParam = skinParam;
 		this.constraints = constraints;
 		this.end = end;
@@ -103,10 +94,9 @@ public class TaskDrawRegular extends AbstractTaskDraw {
 		this.oddEnd = oddEnd;
 		this.paused = new TreeSet<>(((TaskImpl) task).getAllPaused());
 		for (Day tmp = start; tmp.compareTo(end) <= 0; tmp = tmp.increment()) {
-			final int load = toTaskDraw.getDefaultPlan().getLoadAt(tmp);
-			if (load == 0) {
+			final int load = ((TaskImpl) task).getDefaultPlan().getLoadAt(tmp);
+			if (load == 0)
 				this.paused.add(tmp);
-			}
 
 		}
 	}
@@ -158,18 +148,17 @@ public class TaskDrawRegular extends AbstractTaskDraw {
 	}
 
 	private double getOutPosition(double pos2) {
-		if (isThereRightArrow()) {
+		if (isThereRightArrow())
 			return pos2 + 18;
-		}
+
 		return pos2 + 8;
 	}
 
 	private boolean isThereRightArrow() {
-		for (GanttConstraint constraint : constraints) {
-			if (constraint.isThereRightArrow(getTask())) {
+		for (GanttConstraint constraint : constraints)
+			if (constraint.isThereRightArrow(getTask()))
 				return true;
-			}
-		}
+
 		return false;
 	}
 
@@ -193,17 +182,18 @@ public class TaskDrawRegular extends AbstractTaskDraw {
 	}
 
 	private void drawNote(UGraphic ug) {
-		if (note == null) {
+		if (note == null)
 			return;
-		}
+
 		getOpaleNote().drawU(ug);
 
 	}
 
+	@Override
 	public double getHeightMax(StringBounder stringBounder) {
-		if (note == null) {
+		if (note == null)
 			return getFullHeightTask(stringBounder);
-		}
+
 		return getYNotePosition(stringBounder) + getOpaleNote().calculateDimension(stringBounder).getHeight();
 	}
 
@@ -234,9 +224,9 @@ public class TaskDrawRegular extends AbstractTaskDraw {
 	}
 
 	public FingerPrint getFingerPrintNote(StringBounder stringBounder) {
-		if (note == null) {
+		if (note == null)
 			return null;
-		}
+
 		final Dimension2D dim = getOpaleNote().calculateDimension(stringBounder);
 		final double startPos = timeScale.getStartingPosition(start);
 		// final double endPos = timeScale.getEndingPosition(end);
@@ -246,9 +236,9 @@ public class TaskDrawRegular extends AbstractTaskDraw {
 
 	private UGraphic applyColors(UGraphic ug) {
 		final CenterBorderColor col = this.getColors();
-		if (col != null && col.isOk()) {
+		if (col != null && col.isOk())
 			return col.apply(ug);
-		}
+
 		return ug.apply(getLineColor()).apply(getBackgroundColor().bg());
 	}
 
@@ -275,9 +265,8 @@ public class TaskDrawRegular extends AbstractTaskDraw {
 		final double startPos = timeScale.getStartingPosition(start) + margin.getLeft();
 		final double endPos = timeScale.getEndingPosition(end) - margin.getRight();
 
-		if (url != null) {
+		if (url != null)
 			ug.startUrl(url);
-		}
 
 		ug = ug.apply(UTranslate.dy(margin.getTop()));
 
@@ -300,87 +289,9 @@ public class TaskDrawRegular extends AbstractTaskDraw {
 
 		rectangleTask.draw(ug, getShapeHeight(stringBounder), backUndone, oddStart, oddEnd);
 
-		if (url != null) {
+		if (url != null)
 			ug.closeUrl();
-		}
 
 	}
 
-	private void drawShapeOld(UGraphic ug) {
-		final Style style = getStyleSignature().getMergedStyle(getStyleBuilder());
-		final ClockwiseTopRightBottomLeft margin = style.getMargin();
-
-		final double startPos = timeScale.getStartingPosition(start) + margin.getLeft();
-		final double endPos = timeScale.getEndingPosition(end) - margin.getRight();
-
-		double fullLength = endPos - startPos;
-		if (fullLength < 3) {
-			fullLength = 3;
-		}
-		if (url != null) {
-			ug.startUrl(url);
-		}
-
-		ug = ug.apply(UTranslate.dy(margin.getTop()));
-
-		final StringBounder stringBounder = ug.getStringBounder();
-
-		final double round = style.value(PName.RoundCorner).asDouble();
-
-		if (oddStart && !oddEnd) {
-			ug.apply(UTranslate.dx(startPos))
-					.draw(PathUtils.UtoRight(fullLength, getShapeHeight(stringBounder), round));
-		} else if (!oddStart && oddEnd) {
-			ug.apply(UTranslate.dx(startPos)).draw(PathUtils.UtoLeft(fullLength, getShapeHeight(stringBounder), round));
-		} else {
-			final URectangle full = new URectangle(fullLength, getShapeHeight(stringBounder)).rounded(round);
-			if (getCompletion() == 100) {
-				ug.apply(UTranslate.dx(startPos)).draw(full);
-			} else {
-				final double partialLength = fullLength * getCompletion() / 100.;
-				ug.apply(UTranslate.dx(startPos)).apply(HColorUtils.WHITE).apply(HColorUtils.WHITE.bg()).draw(full);
-				if (partialLength > 2) {
-					final URectangle partial = new URectangle(partialLength, getShapeHeight(stringBounder))
-							.rounded(round);
-					ug.apply(UTranslate.dx(startPos)).apply(new HColorNone()).draw(partial);
-				}
-				if (partialLength > 10 && partialLength < fullLength - 10) {
-					final URectangle patch = new URectangle(round, getShapeHeight(stringBounder));
-					ug.apply(UTranslate.dx(startPos)).apply(new HColorNone())
-							.apply(UTranslate.dx(partialLength - round)).draw(patch);
-				}
-				ug.apply(UTranslate.dx(startPos)).apply(new HColorNone().bg()).draw(full);
-			}
-		}
-		if (url != null) {
-			ug.closeUrl();
-		}
-		Day begin = null;
-		for (Day pause : paused) {
-			if (paused.contains(pause.increment())) {
-				if (begin == null)
-					begin = pause;
-			} else {
-				if (begin == null)
-					drawPause(ug, pause, pause);
-				else
-					drawPause(ug, begin, pause);
-				begin = null;
-			}
-		}
-	}
-
-	private void drawPause(UGraphic ug, Day start1, Day end) {
-		final double x1 = timeScale.getStartingPosition(start1);
-		final double x2 = timeScale.getEndingPosition(end);
-		final StringBounder stringBounder = ug.getStringBounder();
-		final URectangle small = new URectangle(x2 - x1 - 1, getShapeHeight(stringBounder) + 1);
-		final ULine line = ULine.hline(x2 - x1 - 1);
-		ug = ug.apply(UTranslate.dx(x1 - 1));
-		ug.apply(HColorUtils.WHITE).apply(HColorUtils.WHITE.bg()).draw(small);
-		final UGraphic ugLine = ug.apply(new UStroke(2, 3, 1));
-		ugLine.draw(line);
-		ugLine.apply(UTranslate.dy(getShapeHeight(stringBounder))).draw(line);
-	}
-
 }
