@@ -39,6 +39,7 @@ import net.sourceforge.plantuml.command.regex.IRegex;
 import net.sourceforge.plantuml.command.regex.RegexLeaf;
 import net.sourceforge.plantuml.command.regex.RegexResult;
 import net.sourceforge.plantuml.project.Failable;
+import net.sourceforge.plantuml.project.GanttConstraintMode;
 import net.sourceforge.plantuml.project.GanttDiagram;
 import net.sourceforge.plantuml.project.core.Moment;
 import net.sourceforge.plantuml.project.core.TaskAttribute;
@@ -47,17 +48,19 @@ import net.sourceforge.plantuml.project.core.TaskInstant;
 public class ComplementBeforeOrAfterOrAtTaskStartOrEnd implements Something {
 
 	private static final int POS_NB1 = 0;
-	private static final int POS_DAY_OR_WEEK1 = 1;
-	private static final int POS_NB2 = 2;
-	private static final int POS_DAY_OR_WEEK2 = 3;
-	private static final int POS_BEFORE_OR_AFTER = 4;
-	private static final int POS_CODE_OTHER = 5;
-	private static final int POS_START_OR_END = 6;
+	private static final int POS_WORKING1 = 1;
+	private static final int POS_DAY_OR_WEEK1 = 2;
+	private static final int POS_NB2 = 3;
+	private static final int POS_WORKING2 = 4;
+	private static final int POS_DAY_OR_WEEK2 = 5;
+	private static final int POS_BEFORE_OR_AFTER = 6;
+	private static final int POS_CODE_OTHER = 7;
+	private static final int POS_START_OR_END = 8;
 
 	public IRegex toRegex(String suffix) { // "+"
 		return new RegexLeaf("COMPLEMENT" + suffix, "(?:at|with|after|" + //
-				"(\\d+)[%s]+(day|week)s?" + //
-				"(?:[%s]+and[%s]+(\\d+)[%s]+(day|week)s?)?" + //
+				"(\\d+)[%s]+(working[%s]+)?(day|week)s?" + //
+				"(?:[%s]+and[%s]+(\\d+)[%s]+(working[%s]+)?(day|week)s?)?" + //
 				"[%s]+(before|after))[%s]+\\[([^\\[\\]]+?)\\].?s[%s]+(start|end)");
 	}
 
@@ -65,9 +68,9 @@ public class ComplementBeforeOrAfterOrAtTaskStartOrEnd implements Something {
 		final String code = arg.get("COMPLEMENT" + suffix, POS_CODE_OTHER);
 		final String startOrEnd = arg.get("COMPLEMENT" + suffix, POS_START_OR_END);
 		final Moment task = system.getExistingMoment(code);
-		if (task == null) {
+		if (task == null)
 			return Failable.error("No such task " + code);
-		}
+
 		TaskInstant result = new TaskInstant(task, TaskAttribute.fromString(startOrEnd));
 		final String nb1 = arg.get("COMPLEMENT" + suffix, POS_NB1);
 		if (nb1 != null) {
@@ -85,10 +88,16 @@ public class ComplementBeforeOrAfterOrAtTaskStartOrEnd implements Something {
 			}
 
 			int delta = days1 + days2;
-			if ("before".equalsIgnoreCase(arg.get("COMPLEMENT" + suffix, POS_BEFORE_OR_AFTER))) {
+			if ("before".equalsIgnoreCase(arg.get("COMPLEMENT" + suffix, POS_BEFORE_OR_AFTER)))
 				delta = -delta;
-			}
-			result = result.withDelta(delta);
+
+			final boolean working = arg.get("COMPLEMENT" + suffix, POS_WORKING1) != null
+					|| arg.get("COMPLEMENT" + suffix, POS_WORKING2) != null;
+
+			final GanttConstraintMode mode = working ? GanttConstraintMode.DO_NOT_COUNT_CLOSE_DAY
+					: GanttConstraintMode.IGNORE_CALENDAR;
+
+			result = result.withDelta(delta, mode, system.getDefaultPlan());
 		}
 		return Failable.ok(result);
 	}
