@@ -57,9 +57,9 @@ public class SolverImpl extends AbstractSolver implements Solver {
 			fullLoad -= loadPlanable.getLoadAt(current);
 			current = current.increment();
 			cpt++;
-			if (cpt > 100000) {
+			if (cpt > 100000)
 				throw new IllegalStateException();
-			}
+
 		}
 		return current.decrement();
 	}
@@ -72,13 +72,13 @@ public class SolverImpl extends AbstractSolver implements Solver {
 		while (fullLoad > 0) {
 			fullLoad -= loadPlanable.getLoadAt(current);
 			current = current.decrement();
-			if (current.getMillis() <= 0) {
+			if (current.getMillis() <= 0)
 				return current;
-			}
+
 			cpt++;
-			if (cpt > 100000) {
+			if (cpt > 100000)
 				throw new IllegalStateException();
-			}
+
 		}
 		return current.increment();
 	}
