@@ -39,6 +39,8 @@ import java.util.ArrayList;
 import java.util.Collection;
 import java.util.List;
 
+import net.sourceforge.plantuml.log.Logme;
+
 class RealMax extends AbstractReal implements Real {
 
 	private final List<Real> all = new ArrayList<>();
@@ -93,7 +95,7 @@ class RealMax extends AbstractReal implements Real {
 	}
 
 	public void printCreationStackTrace() {
-		creationPoint.printStackTrace();
+		Logme.error(creationPoint);
 	}
 
 }
