@@ -41,6 +41,8 @@ import java.util.List;
 import net.sourceforge.plantuml.LineLocation;
 import net.sourceforge.plantuml.StringUtils;
 import net.sourceforge.plantuml.Url;
+import net.sourceforge.plantuml.UrlBuilder;
+import net.sourceforge.plantuml.UrlMode;
 import net.sourceforge.plantuml.command.CommandExecutionResult;
 import net.sourceforge.plantuml.command.SingleLineCommand2;
 import net.sourceforge.plantuml.command.regex.RegexConcat;
@@ -61,25 +63,26 @@ public class CommandReferenceOverSeveral extends SingleLineCommand2<SequenceDiag
 	}
 
 	private static RegexConcat getConcat() {
-		return RegexConcat.build(CommandReferenceOverSeveral.class.getName(), RegexLeaf.start(), //
+		return RegexConcat.build(CommandReferenceOverSeveral.class.getName(), //
+				RegexLeaf.start(), //
 				new RegexLeaf("ref"), //
 				new RegexLeaf("REF", "(#\\w+)?"), //
 				RegexLeaf.spaceOneOrMore(), //
 				new RegexLeaf("over"), //
 				RegexLeaf.spaceOneOrMore(), //
-				new RegexLeaf("PARTS",
-						"(([%pLN_.@]+|[%g][^%g]+[%g])([%s]*,[%s]*([%pLN_.@]+|[%g][^%g]+[%g]))*)"), //
+				new RegexLeaf("PARTS", "(([%pLN_.@]+|[%g][^%g]+[%g])([%s]*,[%s]*([%pLN_.@]+|[%g][^%g]+[%g]))*)"), //
+				RegexLeaf.spaceZeroOrMore(), //
+				new RegexOptional(new RegexLeaf("URL", "(\\[\\[.*?\\]\\])")), //
 				RegexLeaf.spaceZeroOrMore(), //
 				new RegexLeaf(":"), //
 				RegexLeaf.spaceZeroOrMore(), //
-				new RegexOptional(new RegexLeaf("URL", "\\[\\[([^|]*)(?:\\|([^|]*))?\\]\\]")), //
 				new RegexLeaf("TEXT", "(.*)"), RegexLeaf.end());
 	}
 
 	@Override
 	protected CommandExecutionResult executeArg(SequenceDiagram diagram, LineLocation location, RegexResult arg)
 			throws NoSuchColorException {
-		String s1 = arg.get("REF", 0);
+		final String s1 = arg.get("REF", 0);
 		final HColor backColorElement = s1 == null ? null
 				: diagram.getSkinParam().getIHtmlColorSet().getColor(diagram.getSkinParam().getThemeStyle(), s1);
 		// final HtmlColor backColorGeneral =
@@ -87,20 +90,18 @@ public class CommandReferenceOverSeveral extends SingleLineCommand2<SequenceDiag
 
 		final List<String> participants = StringUtils.splitComma(arg.get("PARTS", 0));
 		final String url = arg.get("URL", 0);
-		final String title = arg.get("URL", 1);
 		final String text = StringUtils.trin(arg.get("TEXT", 0));
 
 		final List<Participant> p = new ArrayList<>();
-		for (String s : participants) {
+		for (String s : participants)
 			p.add(diagram.getOrCreateParticipant(StringUtils.eventuallyRemoveStartingAndEndingDoubleQuote(s)));
-		}
 
 		final Display strings = Display.getWithNewlines(text);
 
+		final UrlBuilder b = new UrlBuilder(diagram.getSkinParam().getValue("topurl"), UrlMode.STRICT);
 		Url u = null;
-		if (url != null) {
-			u = new Url(url, title);
-		}
+		if (url != null)
+			u = b.getUrl(url);
 
 		final HColor backColorGeneral = null;
 		final Reference ref = new Reference(p, u, strings, backColorGeneral, backColorElement,
@@ -109,4 +110,4 @@ public class CommandReferenceOverSeveral extends SingleLineCommand2<SequenceDiag
 		return CommandExecutionResult.ok();
 	}
 
-}
+}
\ No newline at end of file
