@@ -35,14 +35,11 @@
  */
 package net.sourceforge.plantuml.skin.rose;
 
-import net.sourceforge.plantuml.awt.geom.Dimension2D;
-
-import net.sourceforge.plantuml.UseStyle;
 import net.sourceforge.plantuml.api.ThemeStyle;
+import net.sourceforge.plantuml.awt.geom.Dimension2D;
 import net.sourceforge.plantuml.graphic.StringBounder;
 import net.sourceforge.plantuml.skin.AbstractComponent;
 import net.sourceforge.plantuml.skin.Area;
-import net.sourceforge.plantuml.skin.ArrowConfiguration;
 import net.sourceforge.plantuml.style.PName;
 import net.sourceforge.plantuml.style.Style;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
@@ -58,16 +55,10 @@ public class ComponentRoseLine extends AbstractComponent {
 	private final boolean continueLine;
 	private final UStroke stroke;
 
-	public ComponentRoseLine(ThemeStyle themeStyle, Style style, HColor color, boolean continueLine, UStroke stroke,
-			HColorSet set) {
+	public ComponentRoseLine(ThemeStyle themeStyle, Style style, boolean continueLine, HColorSet set) {
 		super(style);
-		if (UseStyle.useBetaStyle()) {
-			this.color = style.value(PName.LineColor).asColor(themeStyle, set);
-			this.stroke = style.getStroke();
-		} else {
-			this.color = color;
-			this.stroke = stroke;
-		}
+		this.color = style.value(PName.LineColor).asColor(themeStyle, set);
+		this.stroke = style.getStroke();
 		this.continueLine = continueLine;
 	}
 
@@ -75,12 +66,9 @@ public class ComponentRoseLine extends AbstractComponent {
 	protected void drawInternalU(UGraphic ug, Area area) {
 		final Dimension2D dimensionToUse = area.getDimensionToUse();
 		ug = ug.apply(color);
-		if (UseStyle.useBetaStyle()) {
-			ug = ug.apply(stroke);
-		} else if (continueLine)
-			ug = ug.apply(new UStroke());
-		else
-			ug = ArrowConfiguration.stroke(ug, 5, 5, stroke.getThickness());
+		ug = ug.apply(stroke);
+//		if (continueLine)
+//			ug = ug.apply(new UStroke());
 
 		final int x = (int) (dimensionToUse.getWidth() / 2);
 		ug.apply(UTranslate.dx(x)).draw(ULine.vline(dimensionToUse.getHeight()));
