@@ -36,10 +36,7 @@
 package net.sourceforge.plantuml.skin.rose;
 
 import net.sourceforge.plantuml.ISkinSimple;
-import net.sourceforge.plantuml.UseStyle;
 import net.sourceforge.plantuml.cucadiagram.Display;
-import net.sourceforge.plantuml.graphic.FontConfiguration;
-import net.sourceforge.plantuml.graphic.HorizontalAlignment;
 import net.sourceforge.plantuml.graphic.StringBounder;
 import net.sourceforge.plantuml.graphic.SymbolContext;
 import net.sourceforge.plantuml.skin.AbstractTextualComponent;
@@ -55,15 +52,11 @@ final public class ComponentRoseNoteHexagonal extends AbstractTextualComponent {
 	private final int cornersize = 10;
 	private final SymbolContext symbolContext;
 
-	public ComponentRoseNoteHexagonal(Style style, SymbolContext symbolContext, FontConfiguration font, Display strings,
-			ISkinSimple spriteContainer, HorizontalAlignment alignment) {
-		super(style, spriteContainer.wrapWidth(), strings, font, alignment, 12, 12, 4, spriteContainer, false, null,
-				null);
-		if (UseStyle.useBetaStyle()) {
-			this.symbolContext = style.getSymbolContext(spriteContainer.getThemeStyle(), getIHtmlColorSet());
-		} else {
-			this.symbolContext = symbolContext;
-		}
+	public ComponentRoseNoteHexagonal(Style style, Display strings, ISkinSimple spriteContainer) {
+		super(style, spriteContainer.wrapWidth(), 12, 12, 4, spriteContainer, strings, false);
+
+		this.symbolContext = style.getSymbolContext(spriteContainer.getThemeStyle(), getIHtmlColorSet());
+
 	}
 
 	@Override
@@ -94,12 +87,11 @@ final public class ComponentRoseNoteHexagonal extends AbstractTextualComponent {
 
 		int x2 = (int) getTextWidth(stringBounder);
 		final double diffX = area.getDimensionToUse().getWidth() - getPreferredWidth(stringBounder);
-		if (diffX < 0) {
+		if (diffX < 0)
 			throw new IllegalArgumentException();
-		}
-		if (area.getDimensionToUse().getWidth() > getPreferredWidth(stringBounder)) {
+
+		if (area.getDimensionToUse().getWidth() > getPreferredWidth(stringBounder))
 			x2 = (int) (area.getDimensionToUse().getWidth() - 2 * getPaddingX());
-		}
 
 		final UPolygon polygon = new UPolygon();
 		polygon.addPoint(cornersize, 0);
