@@ -41,6 +41,7 @@ public enum SName {
 	activityDiagram, //
 	actor, //
 	agent, //
+	analog, //
 	archimate, //
 	arrow, //
 	artifact, //
@@ -105,6 +106,7 @@ public enum SName {
 	participant, //
 	partition, //
 	person, //
+	port, //
 	queue, //
 	rectangle, //
 	reference, //
@@ -119,6 +121,7 @@ public enum SName {
 	stack, //
 	stateDiagram, //
 	state, //
+	stateBody, //
 	stereotype, //
 	storage, //
 	swimlane, //
@@ -142,6 +145,7 @@ public enum SName {
 	spotProtocol, //
 	spotStruct, //
 	spotEntity, //
+	spotException, //
 	spotClass, //
 	spotAbstractClass, //
 
