@@ -70,9 +70,9 @@ public class ClusterDecoration {
 	}
 
 	private static USymbol guess(USymbol symbol, PackageStyle style) {
-		if (symbol != null) {
+		if (symbol != null)
 			return symbol;
-		}
+
 		return style.toUSymbol();
 	}
 
