@@ -43,7 +43,7 @@ import net.sourceforge.plantuml.ugraphic.ULine;
 import net.sourceforge.plantuml.ugraphic.UPolygon;
 import net.sourceforge.plantuml.ugraphic.UStroke;
 import net.sourceforge.plantuml.ugraphic.UTranslate;
-import net.sourceforge.plantuml.ugraphic.color.HColorUtils;
+import net.sourceforge.plantuml.ugraphic.color.HColors;
 
 class ExtremityStateLine1 extends Extremity {
 
@@ -75,7 +75,7 @@ class ExtremityStateLine1 extends Extremity {
 
 	public void drawU(UGraphic ug) {
 		ug.apply(ug.getParam().getColor().bg()).apply(new UTranslate(-radius * Math.cos(angle), -radius * Math.sin(angle))).draw(polygon);
-		ug = ug.apply(HColorUtils.WHITE.bg());
+		ug = ug.apply(HColors.WHITE.bg());
 		ug.apply(new UStroke(1.5)).apply(new UTranslate(dest.getX() - radius, dest.getY() - radius)).draw(new UEllipse(radius * 2, radius * 2));
 		drawLine(ug, getPointOnCircle(dest.getX(), dest.getY(), Math.PI / 4),
 				getPointOnCircle(dest.getX(), dest.getY(), Math.PI + Math.PI / 4));
