@@ -43,7 +43,7 @@ import net.sourceforge.plantuml.graphic.UDrawable;
 import net.sourceforge.plantuml.ugraphic.UEllipse;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
 import net.sourceforge.plantuml.ugraphic.UTranslate;
-import net.sourceforge.plantuml.ugraphic.color.HColorUtils;
+import net.sourceforge.plantuml.ugraphic.color.HColors;
 
 public class ConnectedCircle implements UDrawable {
 
@@ -63,7 +63,7 @@ public class ConnectedCircle implements UDrawable {
 			final UEllipse part = new UEllipse(2 * radius, 2 * radius, angle - delta, 2 * delta);
 			ug.draw(part);
 		}
-		ug = ug.apply(HColorUtils.GREEN).apply(HColorUtils.GREEN.bg());
+		ug = ug.apply(HColors.GREEN).apply(HColors.GREEN.bg());
 		for (Point2D pt : points) {
 			final UTranslate tr = new UTranslate(pt);
 			// ug.apply(tr).draw(new UEllipse(2, 2));
