@@ -45,8 +45,7 @@ import net.sourceforge.plantuml.svek.ShapeType;
 import net.sourceforge.plantuml.ugraphic.UEllipse;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
 import net.sourceforge.plantuml.ugraphic.UShape;
-import net.sourceforge.plantuml.ugraphic.color.HColorNone;
-import net.sourceforge.plantuml.ugraphic.color.HColorUtils;
+import net.sourceforge.plantuml.ugraphic.color.HColors;
 
 public class EntityImageAssociationPoint extends AbstractEntityImage {
 
@@ -62,7 +61,7 @@ public class EntityImageAssociationPoint extends AbstractEntityImage {
 
 	final public void drawU(UGraphic ug) {
 		final UShape circle = new UEllipse(SIZE, SIZE);
-		ug.apply(new HColorNone()).apply(HColorUtils.BLACK.bg()).draw(circle);
+		ug.apply(HColors.none()).apply(HColors.BLACK.bg()).draw(circle);
 	}
 
 	public ShapeType getShapeType() {
