@@ -35,25 +35,19 @@
  */
 package net.sourceforge.plantuml.svek.image;
 
-import net.sourceforge.plantuml.awt.geom.Dimension2D;
-
 import java.awt.geom.Rectangle2D;
 import java.util.EnumMap;
 import java.util.Map;
 
-import net.sourceforge.plantuml.ColorParam;
 import net.sourceforge.plantuml.CornerParam;
 import net.sourceforge.plantuml.Dimension2DDouble;
 import net.sourceforge.plantuml.FontParam;
 import net.sourceforge.plantuml.Guillemet;
 import net.sourceforge.plantuml.ISkinParam;
 import net.sourceforge.plantuml.LineConfigurable;
-import net.sourceforge.plantuml.LineParam;
-import net.sourceforge.plantuml.SkinParamUtils;
 import net.sourceforge.plantuml.Url;
-import net.sourceforge.plantuml.UseStyle;
+import net.sourceforge.plantuml.awt.geom.Dimension2D;
 import net.sourceforge.plantuml.creole.Stencil;
-import net.sourceforge.plantuml.cucadiagram.Bodier;
 import net.sourceforge.plantuml.cucadiagram.Display;
 import net.sourceforge.plantuml.cucadiagram.EntityPortion;
 import net.sourceforge.plantuml.cucadiagram.ILeaf;
@@ -103,12 +97,8 @@ public class EntityImageObject extends AbstractEntityImage implements Stencil, W
 		final Stereotype stereotype = entity.getStereotype();
 		this.roundCorner = skinParam.getRoundCorner(CornerParam.DEFAULT, null);
 
-		final FontConfiguration fcHeader;
-		if (UseStyle.useBetaStyle())
-			fcHeader = getStyleHeader().getFontConfiguration(getSkinParam().getThemeStyle(),
-					getSkinParam().getIHtmlColorSet());
-		else
-			fcHeader = FontConfiguration.create(getSkinParam(), FontParam.OBJECT, stereotype);
+		final FontConfiguration fcHeader = getStyleHeader().getFontConfiguration(getSkinParam().getThemeStyle(),
+				getSkinParam().getIHtmlColorSet());
 
 		final TextBlock tmp = getUnderlinedName(entity).create(fcHeader, HorizontalAlignment.CENTER, skinParam);
 		this.name = TextBlockUtils.withMargin(tmp, 2, 2);
@@ -172,29 +162,23 @@ public class EntityImageObject extends AbstractEntityImage implements Stencil, W
 		final double heightTotal = dimTotal.getHeight();
 		final Shadowable rect = new URectangle(widthTotal, heightTotal).rounded(roundCorner);
 
-		final HColor borderColor;
-		final UStroke stroke;
 		HColor backcolor = getEntity().getColors().getColor(ColorType.BACK);
+		HColor headerBackcolor = getEntity().getColors().getColor(ColorType.HEADER);
 
-		if (UseStyle.useBetaStyle()) {
-			final Style style = getStyle();
-			borderColor = style.value(PName.LineColor).asColor(getSkinParam().getThemeStyle(),
+		final Style style = getStyle();
+		final HColor borderColor = style.value(PName.LineColor).asColor(getSkinParam().getThemeStyle(),
+				getSkinParam().getIHtmlColorSet());
+
+		if (headerBackcolor == null)
+			headerBackcolor = backcolor == null ? getStyleHeader().value(PName.BackGroundColor)
+					.asColor(getSkinParam().getThemeStyle(), getSkinParam().getIHtmlColorSet()) : backcolor;
+
+		if (backcolor == null)
+			backcolor = style.value(PName.BackGroundColor).asColor(getSkinParam().getThemeStyle(),
 					getSkinParam().getIHtmlColorSet());
-			if (backcolor == null)
-				backcolor = style.value(PName.BackGroundColor).asColor(getSkinParam().getThemeStyle(),
-						getSkinParam().getIHtmlColorSet());
-			rect.setDeltaShadow(style.value(PName.Shadowing).asDouble());
-			stroke = style.getStroke();
 
-		} else {
-			if (getSkinParam().shadowing(getEntity().getStereotype()))
-				rect.setDeltaShadow(4);
-			borderColor = SkinParamUtils.getColor(getSkinParam(), getStereo(), ColorParam.objectBorder);
-			if (backcolor == null)
-				backcolor = SkinParamUtils.getColor(getSkinParam(), getStereo(), ColorParam.objectBackground);
-			stroke = getStroke();
-
-		}
+		rect.setDeltaShadow(style.value(PName.Shadowing).asDouble());
+		final UStroke stroke = style.getStroke();
 
 		ug = ug.apply(borderColor).apply(backcolor.bg());
 
@@ -207,6 +191,12 @@ public class EntityImageObject extends AbstractEntityImage implements Stencil, W
 		ug.startGroup(typeIDent);
 		ug.apply(stroke).draw(rect);
 
+		if (roundCorner == 0 && headerBackcolor != null && backcolor.equals(headerBackcolor) == false) {
+			final Shadowable rect2 = new URectangle(widthTotal, dimTitle.getHeight());
+			final UGraphic ugHeader = ug.apply(headerBackcolor.bg());
+			ugHeader.apply(stroke).draw(rect2);
+		}
+
 		final ULayoutGroup header = getLayout(stringBounder);
 		header.drawU(ug, dimTotal.getWidth(), dimTitle.getHeight());
 
@@ -228,17 +218,6 @@ public class EntityImageObject extends AbstractEntityImage implements Stencil, W
 		return header;
 	}
 
-	private UStroke getStroke() {
-		UStroke stroke = lineConfig.getColors().getSpecificLineStroke();
-		if (stroke == null)
-			stroke = getSkinParam().getThickness(LineParam.objectBorder, getStereo());
-
-		if (stroke == null)
-			stroke = new UStroke(1.5);
-
-		return stroke;
-	}
-
 	private double getMethodOrFieldHeight(final Dimension2D dim) {
 		final double fieldsHeight = dim.getHeight();
 		if (fieldsHeight == 0)
