@@ -45,6 +45,7 @@ import net.sourceforge.plantuml.FileFormat;
 import net.sourceforge.plantuml.FileFormatOption;
 import net.sourceforge.plantuml.Log;
 import net.sourceforge.plantuml.SourceStringReader;
+import net.sourceforge.plantuml.log.Logme;
 
 class AcceptTelnetClient extends Thread {
 	final private Socket clientSocket;
@@ -85,7 +86,7 @@ class AcceptTelnetClient extends Thread {
 			os.close();
 			br.close();
 		} catch (IOException e) {
-			e.printStackTrace();
+			Logme.error(e);
 		}
 
 	}
