@@ -40,6 +40,7 @@ import java.util.Set;
 
 import net.sourceforge.plantuml.DefinitionsContainer;
 import net.sourceforge.plantuml.StringLocated;
+import net.sourceforge.plantuml.log.Logme;
 import net.sourceforge.plantuml.preproc.Defines;
 import net.sourceforge.plantuml.preproc.FileWithSuffix;
 import net.sourceforge.plantuml.preproc.ImportedFiles;
@@ -57,7 +58,7 @@ public class TimLoader {
 		try {
 			defines.copyTo(global);
 		} catch (EaterException e) {
-			e.printStackTrace();
+			Logme.error(e);
 		}
 	}
 
