@@ -53,13 +53,7 @@ public abstract class AbstractColorMapper implements ColorMapper {
 		if (hcolor == null)
 			return "none";
 
-		if (hcolor instanceof HColorBackground) {
-			hcolor = ((HColorBackground) hcolor).getBack();
-//			Thread.dumpStack();
-//			System.exit(0);
-//			return toHtml(result);
-		}
-		if (HColorUtils.isTransparent(hcolor))
+		if (HColors.isTransparent(hcolor))
 			return "#00000000";
 
 		final Color color = toColor(hcolor);
