@@ -42,6 +42,8 @@ public interface HColor extends UChange {
 
 	public UBackground bg();
 
+	public HColor withDark(HColor dark);
+
 	public HColor darken(int ratio);
 
 	public HColor lighten(int ratio);
@@ -56,4 +58,6 @@ public interface HColor extends UChange {
 
 	public HColor darkSchemeTheme();
 
+	public HColor opposite();
+
 }
