@@ -37,7 +37,6 @@ package net.sourceforge.plantuml.ugraphic.debug;
 import static java.nio.charset.StandardCharsets.UTF_8;
 
 import java.awt.Color;
-import net.sourceforge.plantuml.awt.geom.Dimension2D;
 import java.awt.geom.Point2D;
 import java.io.IOException;
 import java.io.OutputStream;
@@ -47,6 +46,7 @@ import java.util.Date;
 import java.util.List;
 import java.util.Locale;
 
+import net.sourceforge.plantuml.awt.geom.Dimension2D;
 import net.sourceforge.plantuml.posimo.DotPath;
 import net.sourceforge.plantuml.ugraphic.AbstractCommonUGraphic;
 import net.sourceforge.plantuml.ugraphic.ClipContainer;
@@ -66,7 +66,7 @@ import net.sourceforge.plantuml.ugraphic.color.ColorMapperIdentity;
 import net.sourceforge.plantuml.ugraphic.color.HColor;
 import net.sourceforge.plantuml.ugraphic.color.HColorMiddle;
 import net.sourceforge.plantuml.ugraphic.color.HColorSimple;
-import net.sourceforge.plantuml.ugraphic.color.HColorUtils;
+import net.sourceforge.plantuml.ugraphic.color.HColors;
 
 public class UGraphicDebug extends AbstractCommonUGraphic implements ClipContainer {
 
@@ -98,7 +98,7 @@ public class UGraphicDebug extends AbstractCommonUGraphic implements ClipContain
 
 	public UGraphicDebug(double scaleFactor, Dimension2D dim, String svgLinkTarget, String hoverPathColorRGB, long seed,
 			String preserveAspectRatio) {
-		super(HColorUtils.WHITE, new ColorMapperIdentity(), new StringBounderDebug());
+		super(HColors.WHITE, new ColorMapperIdentity(), new StringBounderDebug());
 		this.output = new ArrayList<>();
 		this.scaleFactor = scaleFactor;
 		this.dim = dim;
@@ -255,15 +255,13 @@ public class UGraphicDebug extends AbstractCommonUGraphic implements ClipContain
 	}
 
 	private String colorToString(HColor color) {
-		if (color == null) {
+		if (color == null)
 			return "NULL_COLOR";
-		}
+
 		if (color instanceof HColorSimple) {
 			final HColorSimple simple = (HColorSimple) color;
 			final Color internal = simple.getColor999();
-			if (simple.isMonochrome()) {
-				return "monochrome " + Integer.toHexString(internal.getRGB());
-			}
+
 			return Integer.toHexString(internal.getRGB());
 		}
 		if (color instanceof HColorMiddle) {
