@@ -51,7 +51,7 @@ import net.sourceforge.plantuml.ugraphic.UText;
 import net.sourceforge.plantuml.ugraphic.color.ColorMapper;
 import net.sourceforge.plantuml.ugraphic.color.HColor;
 import net.sourceforge.plantuml.ugraphic.color.HColorGradient;
-import net.sourceforge.plantuml.ugraphic.color.HColorUtils;
+import net.sourceforge.plantuml.ugraphic.color.HColors;
 
 public class DriverTextSvg implements UDriver<UText, SvgGraphics> {
 
@@ -70,7 +70,7 @@ public class DriverTextSvg implements UDriver<UText, SvgGraphics> {
 		}
 
 		final FontConfiguration fontConfiguration = shape.getFontConfiguration();
-		if (HColorUtils.isTransparent(fontConfiguration.getColor())) {
+		if (HColors.isTransparent(fontConfiguration.getColor())) {
 			return;
 		}
 		final UFont font = fontConfiguration.getFont();
