@@ -47,6 +47,7 @@ import net.sourceforge.plantuml.cucadiagram.dot.ExeState;
 import net.sourceforge.plantuml.cucadiagram.dot.Graphviz;
 import net.sourceforge.plantuml.cucadiagram.dot.GraphvizVersion;
 import net.sourceforge.plantuml.cucadiagram.dot.ProcessState;
+import net.sourceforge.plantuml.log.Logme;
 
 public class GraphvizJs implements Graphviz {
 
@@ -72,7 +73,7 @@ public class GraphvizJs implements Graphviz {
 				try {
 					this.engine = new VizJsEngine();
 				} catch (Exception e) {
-					e.printStackTrace();
+					Logme.error(e);
 				}
 			}
 			runnable.run();
@@ -92,7 +93,7 @@ public class GraphvizJs implements Graphviz {
 			os.write(svg.getBytes());
 			return ProcessState.TERMINATED_OK();
 		} catch (Exception e) {
-			e.printStackTrace();
+			Logme.error(e);
 			throw new GraphvizJsRuntimeException(e);
 		}
 	}
