@@ -53,6 +53,7 @@ import net.sourceforge.plantuml.graphic.VerticalAlignment;
 import net.sourceforge.plantuml.json.JsonValue;
 import net.sourceforge.plantuml.jsondiagram.JsonDiagram;
 import net.sourceforge.plantuml.jsondiagram.StyleExtractor;
+import net.sourceforge.plantuml.log.Logme;
 
 public class YamlDiagramFactory extends PSystemAbstractFactory {
 
@@ -83,7 +84,7 @@ public class YamlDiagramFactory extends PSystemAbstractFactory {
 			}
 			yaml = new SimpleYamlParser().parse(list);
 		} catch (Exception e) {
-			e.printStackTrace();
+			Logme.error(e);
 		}
 		final JsonDiagram result = new JsonDiagram(style, source, UmlDiagramType.YAML, yaml, highlighted);
 		if (styleExtractor != null) {
